@@ -69,7 +69,8 @@ class Department(BaseModel):
             i_dict = {
                 "id": i.id,
                 "name": i.name,
-                "path": i.path
+                "path": i.path,
+                "show_order": i.show_order,
             }
             if path_str not in child_map:
                 child_map[path_str] = [i_dict]
@@ -82,7 +83,8 @@ class Department(BaseModel):
             "id": self.id,
             "name": self.name,
             "path": [],
-            "children": child_map.get(str(self.id), [])
+            "show_order": self.show_order,
+            "children": child_map.get(str(self.id), []),
         }
         self.child_map = child_map
         # 递归调用
@@ -124,3 +126,40 @@ class UserInformation(BaseModel):
 
     class Meta:
         db_table = 'user_information'
+
+
+class Roles(BaseModel):
+    """"
+    角色表
+    """
+    name = models.CharField(max_length=32, verbose_name="角色名称")
+    desc = models.CharField(max_length=255, null=True, blank=True, verbose_name="角色描述")
+    code = models.CharField(max_length=32, verbose_name="角色code", unique=True)
+    organization_id = models.IntegerField(verbose_name="组织id")
+    is_deleted = models.BooleanField(default=False, verbose_name="是否已经被删除")
+    is_edited = models.BooleanField(default=False, verbose_name="是否可以编辑")
+
+    def __str__(self):
+        return self.name
+
+    class Meta:
+        db_table = "role"
+        verbose_name = "角色"
+
+
+class UserRoles(BaseModel):
+    """
+    用户角色表
+    """
+    user_id = models.IntegerField(
+        verbose_name="用户ID"
+    )
+    role = models.ForeignKey(
+        Roles,
+        on_delete=models.CASCADE,
+        verbose_name="角色"
+    )
+
+    class Meta:
+        db_table = "user_role"
+        verbose_name = "用户角色关系表"
